pub struct VerifiedData {
pub credentials: Vec<CredentialRecord>,
pub addresses: Vec<CredentialAddress>,
pub primary_id: CredentialId,
pub override_primary: bool,
pub has_natives: bool,
pub has_extensions: bool,
pub nonce: u64,
}Fields
credentials: Vec<CredentialRecord>a list of verified credentials that have passed all checks
addresses: Vec<CredentialAddress>a list of addresses (recognized by the environment) were derived from the credentials
primary_id: CredentialIdan id of a credential that is considered primary in the batch
override_primary: boolin case if we updating an existing state with new credentials, this flag indicates whether to override the existing primary credential with the primary from this batch
has_natives: boola flag indicating that the batch has credentials native to the environment like caller or `info.sender``
has_extensions: boola flag indicating that there is at least one credential wuth addutional properties to be reused e.g. `Passkeys``
nonce: u64a nonce value used for replay attack protection